==> wmconfig-1.2.5.tar.bz2: wmconfig-1.2.5/ude.c <==
/*
 * Copyright (C) 2004 Tommy Scheunemann
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

/*
 * Functions needed for producing an Ude (Unix Desktop Environment) configuration
 */

#include "wmconfig.h"
#include "prototypes.h"
#include "package.h"

#include <stdio.h>
#include <stdlib.h>
#include <assert.h>
#include <strings.h>

/*
 * Outputs on configuration stdout
 */
static void output_ude_level(struct group *root, int level, char *use_term);

void output_ude(struct group *root, char *use_term) {
    return output_ude_level(root, 0, use_term);
}

void output_ude_level(struct group *root, int level, char *use_term)
{
    struct item *item;
    int sp;

    if (root == (struct group *)NULL)
        return;

    if (level > 0) {
        for (sp = 1; sp < level; sp++) putchar(' ');
        printf("SUBMENU \"%s\" folder {\n", (level == 0) ? "Programs" : root->name);
    }

    item = root->items;
    while (item->type != 0) {
        if (item->type == ITEM_MENU) {
	    struct group *subgroup = (struct group *)item->data;
            output_ude_level(subgroup, level + 1, use_term);
	} else if (item->type == ITEM_APP) {

            struct package *app;

	    app = (struct package *)item->data;
	    
	    if (! app->restart)
 	    if (app->name && app->exec) {
        	for (sp = 1; sp <= level; sp++)
		    putchar(' ');

		printf("ITEM \"%s\": ", app->name);
					
                /* this removes ending '&' that should not be there */
                {
                    char *b;
                    int l;

                    b = app->exec;
                    l = strlen(b);

		/* Check for terminal */
		    if (app->terminal)
			printf ("\"%s -e ", use_term);
		    putchar ('\"');
                    while (l > 0 && b[l - 1] == ' ')
                        l--;
                    if (l > 0 && b[l - 1] == '&')
                        l--;
                    for (; l > 0; l--,b++)
                        putchar(*b);
                    printf("\";\n");
                }
	    }
	}
	item++;
    }
    if (level > 0) {
        for (sp = 1; sp < level; sp++) putchar(' ');
        printf("}\n");
    }
}

==> wmconfig-1.3.2.tar.bz2: wmconfig-1.3.2/ude.c <==
/*
 * Copyright (C) 2004 Tommy Scheunemann
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

/*
 * Functions needed for producing an Ude (Unix Desktop Environment) configuration
 */

#include "wmconfig.h"
#include "prototypes.h"
#include "package.h"

#include <stdio.h>
#include <stdlib.h>
#include <assert.h>
#include <strings.h>
#include <string.h>

/*
 * Outputs on configuration stdout
 */
static void output_ude_level(struct group *root, int level,const char *use_term);

void output_ude(struct group *root,const char *use_term) {
    return output_ude_level(root, 0, use_term);
}

void output_ude_level(struct group *root, int level,const char *use_term)
{
    struct item *item;
    int sp;

    if (root == (struct group *)NULL)
        return;

    if (level > 0) {
        for (sp = 1; sp < level; sp++) putchar(' ');
        printf("SUBMENU \"%s\" folder {\n", (level == 0) ? "Programs" : root->name);
    }

    item = root->items;
    while (item->type != 0) {
        if (item->type == ITEM_MENU) {
	    struct group *subgroup = (struct group *)item->data;
            output_ude_level(subgroup, level + 1, use_term);
	} else if (item->type == ITEM_APP) {

            struct package *app;

	    app = (struct package *)item->data;
	    
	    if (! app->restart)
 	    if (app->name && app->exec) {
        	for (sp = 1; sp <= level; sp++)
		    putchar(' ');

		printf("ITEM \"%s\": ", app->name);
					
                /* this removes ending '&' that should not be there */
                {
                    char *b;
                    int l;

                    b = app->exec;
                    l = strlen(b);

		/* Check for terminal */
		    if (app->terminal)
			printf ("\"%s -e ", use_term);
		    putchar ('\"');
                    while (l > 0 && b[l - 1] == ' ')
                        l--;
                    if (l > 0 && b[l - 1] == '&')
                        l--;
                    for (; l > 0; l--,b++)
                        putchar(*b);
                    printf("\";\n");
                }
	    }
	}
	item++;
    }
    if (level > 0) {
        for (sp = 1; sp < level; sp++) putchar(' ');
        printf("}\n");
    }
}
